@@ -1,7 +1,14 @@
 #! /usr/bin/env python
-import sys, os, re, zipfile, shutil, urllib2, urllib, subprocess, re, tempfile, urlparse
-from progressbar import ProgressBar, Percentage, Bar, FormatLabel
+import os
+import sys
+import re
+import zipfile
+import shutil
+import urllib2
 import subprocess
+import tempfile
+import urllib
+
 
 class BaseInstaller(object):
     wpm_meta_path = os.path.expanduser('~/.wpm/')
@@ -9,53 +16,38 @@ class BaseInstaller(object):
     tmp_dir = tempfile.mkdtemp()
     plugins_svn = "http://plugins.svn.wordpress.org"
     target_location = None
+    plugin_name = ''
 
     def __init__(self, *args, **kwargs):
 
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-    """
-    Common method to download a file from a given url
-    """
     def download_file(self, url):
-        return self.download_data(url)
+        """ Common method to download a file from a given url """
 
-
-    def download_data(self, url):
-
-        pbar = ProgressBar(widgets=[FormatLabel('Downloading'), Percentage(), Bar()],
-            maxval=9000000).start()
+        print 'Fetching %s' % url
 
         temp = tempfile.mkstemp()
 
-        p = subprocess.Popen(['wget', '-O', temp[1], url], stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE)
-
-        while p.poll() != 0:
-            pbar.update(os.stat(temp[1]).st_size)
-
-        pbar.finish()
+        urllib.urlretrieve(url, temp[1])
 
         return temp[1]
 
-
-    """
-    Unzip a plugin in .zip format
-    """
     def extract(self, file):
-        print "\r\nUnzipping ..."
+        """ Extract the contents of a zip file """
+
+        print "Unzipping %s" % file
+
         z = zipfile.ZipFile(file)
+
         z.extractall(self.tmp_dir)
+
         return z.namelist()
 
-        #return os.path.join(self.tmp_dir, z.namelist())
-
-
-    """
-    Writes new security keys to the wp-config.php file
-    """
-    def set_security_keys(self, config_file = None):
+    def set_security_keys(self, config_file=None):
+        """ Generates new security keys and writes them
+            to the wp-config.php file """
 
         if not config_file:
             return
@@ -63,12 +55,14 @@ class BaseInstaller(object):
         print "Generating new security keys"
 
         try:
-            keys = urllib2.urlopen('https://api.wordpress.org/secret-key/1.1/salt/').readlines()
+            keys = urllib2.urlopen(
+                'https://api.wordpress.org/secret-key/1.1/salt/').readlines()
         except:
             print "Couldn't generate security keys from WordPress API. You'll have to set them yourself."
-            return;
+            return
+
+        config_file = open(self.target_location + '/wp-config.php', 'r+')
 
-        config_file = open(self.target_location+'/wp-config.php','r+')
         lines = config_file.readlines()
 
         for i in range(len(lines)):
@@ -78,20 +72,21 @@ class BaseInstaller(object):
                     lines[i] = key
 
         config_file.seek(0)
+
         config_file.writelines(lines)
 
-    """
-    Runs a command
-    """
     def run_command(self, cmd_list):
-        proc = subprocess.Popen(cmd_list,stdout=subprocess.PIPE)
+        """ Runs a shell command command """
+
+        proc = subprocess.Popen(cmd_list, stdout=subprocess.PIPE)
+
         for line in proc.stdout:
-            if line is not "\r\n": print line
+            if line is not "\r\n":
+                print line
 
-    """
-    Moves the tmp install to the specified plugin location
-    """
     def move_tmp(self, src, dest):
+        """ Renames the tmp installation dir to the
+            specified destination """
 
         if os.path.exists(os.path.abspath(dest)) and not self.overwrite:
             print "Installation already exists"
@@ -104,69 +99,110 @@ class BaseInstaller(object):
 
         shutil.move(src, dest)
 
+    def install(self):
+
+        if os.path.exists(os.path.join(self.target_location, self.plugin_name)) and not self.overwrite:
+            print "Target location for %s exists. Aborting." % self.plugin_name
+            return False
+
+        return True
+
 
 class ZIPInstaller(BaseInstaller):
 
-    def __init__(self, *args, **kwargs):
-        super(ZIPInstaller, self).__init__(*args, **kwargs)
-
+    """ Downloads, unpacks and relocates
+        a remote zip file """
 
     def install(self):
+        _continue = super(ZIPInstaller, self).install()
+
+        if _continue is False:
+            return
 
         target_location = os.path.join(self.target_location, self.plugin_name)
 
         file = self.download_file(self.url)
 
-        extracted_files = self.extract(file)
+        self.extract(file)
 
         self.move_tmp(self.tmp_dir, target_location)
 
         return True
 
+
 class GITInstaller(BaseInstaller):
-    """
-    Clones a git repository
-    """
-    def install(self):
-        print "Cloning %s from %s" % (self.plugin_name, self.url)
-        self.run_command(['git','clone', self.url, os.path.join(self.target_location, self.plugin_name) ])
 
-
-"""
-Exports from the trunk of an svn repository
-"""
-class SVNInstaller(BaseInstaller):
+    """ Clones a git repository """
 
     def install(self):
-        print "Exporting %s from %s" % (self.plugin_name, self.svn_url)
-        self._run_command(['svn','export', url, self.target_location ])
+        _continue = super(GITInstaller, self).install()
 
-"""
-Download and extract the specified plugin from the
-official WordPress plugin repository
-"""
-class WPInstaller(BaseInstaller):
-
-    def install(self):
-
-        if os.path.exists(
-            os.path.join(self.target_location, self.plugin_name)) and not self.overwrite:
-            print "Target location exists. Aborting"
+        if _continue is False:
             return
 
-        svn_url = '/'.join([self.plugins_svn, self.plugin_name.replace("\n",''), 'trunk'])
-        print "Exporting %s from Wordpress SVN" % (self.plugin_name)
-        self.run_command(['svn', 'export', svn_url,
-            os.path.join(self.target_location, self.plugin_name)])
+        print "Cloning %s from %s" % (self.plugin_name, self.url)
 
-"""
-Creates the wpm meta directory, and downlods the list of available plugins.
-"""
-class DBInstaller(BaseInstaller):
+        self.run_command(
+            ['git', 'clone', self.url, os.path.join(self.target_location, self.plugin_name)])
+
+
+class SVNInstaller(BaseInstaller):
+
+    """ Exports from the trunk of an svn repository """
+
+    def install(self):
+        _continue = super(SVNInstaller, self).install()
+
+        if _continue is False:
+            return
+
+        print "Exporting %s from %s" % (self.plugin_name, self.svn_url)
+
+        self._run_command(['svn', 'export', self.url, self.target_location])
+
+
+class WPInstaller(BaseInstaller):
+
+    """ Download and extract the specified plugin from the
+        official WordPress SVN plugin repository """
+
+    def install(self):
+        super(WPInstaller, self).install()
+
+        """ Build the url to the svn repo """
+        svn_url = '/'.join([self.plugins_svn,
+                            self.plugin_name.replace("\n", ''), 'trunk'])
+
+        print "Exporting %s from Wordpress SVN" % (self.plugin_name)
+
+        self.run_command(['svn', 'export', svn_url,
+                          os.path.join(self.target_location, self.plugin_name)])
+
+
+class FrameworkInstaller(ZIPInstaller):
+
+    """ Downlads and installs the WP framework """
 
     def install(self):
 
-        data = self.download_data(self.plugins_svn)
+        file = self.download_file(self.url)
+
+        self.extract(file)
+
+        self.move_tmp(
+            os.path.join(self.tmp_dir, 'wordpress'), self.target_location)
+
+        return True
+
+
+class DBInstaller(BaseInstaller):
+
+    """ Creates the wpm meta directory,
+        and downlods the list of available plugins. """
+
+    def install(self):
+
+        data = self.download_file(self.plugins_svn)
 
         try:
             os.mkdir(self.wpm_meta_path)
@@ -175,9 +211,9 @@ class DBInstaller(BaseInstaller):
 
         local = open(self.plugin_db_path, 'w+')
 
-        existing_contents = list(local.read())
+        list(local.read())
 
-        plugins = re.findall('">(.*)/</a>',data)
+        plugins = re.findall('">(.*)/</a>', data)
 
         local.seek(0)
         local.write("\r\n".join(plugins))
